@@ -20,6 +20,8 @@ from datetime import timedelta
 
 # remove username from the default django user model. (Creating a custom user model based on the original django model)
 # email is used as the unique account 'username'
+import logging
+logger = logging.getLogger(__name__)
 
 
 class UserManager(BaseUserManager):
